==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/Compute/AmazonEc2AwsInferentia.md <==
# AmazonEc2AwsInferentia


```text
aws-q3-2021/Resource/Compute/AmazonEc2AwsInferentia
```

```text
include('aws-q3-2021/Resource/Compute/AmazonEc2AwsInferentia')
```



| Illustration | AmazonEc2AwsInferentia | AmazonEc2AwsInferentiaCard | AmazonEc2AwsInferentiaGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Compute/AmazonEc2AwsInferentia.png) | ![illustration for AmazonEc2AwsInferentia](../../../aws-q3-2021/Resource/Compute/AmazonEc2AwsInferentia.Local.png) | ![illustration for AmazonEc2AwsInferentiaCard](../../../aws-q3-2021/Resource/Compute/AmazonEc2AwsInferentiaCard.Local.png) | ![illustration for AmazonEc2AwsInferentiaGroup](../../../aws-q3-2021/Resource/Compute/AmazonEc2AwsInferentiaGroup.Local.png) |




## AmazonEc2AwsInferentia

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2AwsInferentia
include('aws-q3-2021/Resource/Compute/AmazonEc2AwsInferentia')

' renders the element
AmazonEc2AwsInferentia('AmazonEc2AwsInferentia', 'Amazon Ec2 Aws Inferentia', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2AwsInferentia
include('aws-q3-2021/Resource/Compute/AmazonEc2AwsInferentia')

' renders the element
AmazonEc2AwsInferentia('AmazonEc2AwsInferentia', 'Amazon Ec2 Aws Inferentia', 'an optional tech label')
@enduml
```

## AmazonEc2AwsInferentiaCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2AwsInferentiaCard
include('aws-q3-2021/Resource/Compute/AmazonEc2AwsInferentia')

' renders the element
AmazonEc2AwsInferentiaCard('AmazonEc2AwsInferentiaCard', 'Amazon Ec2 Aws Inferentia Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2AwsInferentiaCard
include('aws-q3-2021/Resource/Compute/AmazonEc2AwsInferentia')

' renders the element
AmazonEc2AwsInferentiaCard('AmazonEc2AwsInferentiaCard', 'Amazon Ec2 Aws Inferentia Card', 'an optional description')
@enduml
```

## AmazonEc2AwsInferentiaGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2AwsInferentiaGroup
include('aws-q3-2021/Resource/Compute/AmazonEc2AwsInferentia')

' renders the element
AmazonEc2AwsInferentiaGroup('AmazonEc2AwsInferentiaGroup', 'Amazon Ec2 Aws Inferentia Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2AwsInferentiaGroup
include('aws-q3-2021/Resource/Compute/AmazonEc2AwsInferentia')

' renders the element
AmazonEc2AwsInferentiaGroup('AmazonEc2AwsInferentiaGroup', 'Amazon Ec2 Aws Inferentia Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-q3-2021/Resource/Compute/AmazonEc2AwsInferentia.md <==
# AmazonEc2AwsInferentia


```text
aws-q3-2021/Resource/Compute/AmazonEc2AwsInferentia
```

```text
include('aws-q3-2021/Resource/Compute/AmazonEc2AwsInferentia')
```



| Illustration | AmazonEc2AwsInferentia | AmazonEc2AwsInferentiaCard | AmazonEc2AwsInferentiaGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Compute/AmazonEc2AwsInferentia.png) | ![illustration for AmazonEc2AwsInferentia](../../../aws-q3-2021/Resource/Compute/AmazonEc2AwsInferentia.Local.png) | ![illustration for AmazonEc2AwsInferentiaCard](../../../aws-q3-2021/Resource/Compute/AmazonEc2AwsInferentiaCard.Local.png) | ![illustration for AmazonEc2AwsInferentiaGroup](../../../aws-q3-2021/Resource/Compute/AmazonEc2AwsInferentiaGroup.Local.png) |




## AmazonEc2AwsInferentia

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2AwsInferentia
include('aws-q3-2021/Resource/Compute/AmazonEc2AwsInferentia')

' renders the element
AmazonEc2AwsInferentia('AmazonEc2AwsInferentia', 'Amazon Ec2 Aws Inferentia', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2AwsInferentia
include('aws-q3-2021/Resource/Compute/AmazonEc2AwsInferentia')

' renders the element
AmazonEc2AwsInferentia('AmazonEc2AwsInferentia', 'Amazon Ec2 Aws Inferentia', 'an optional tech label')
@enduml
```

## AmazonEc2AwsInferentiaCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2AwsInferentiaCard
include('aws-q3-2021/Resource/Compute/AmazonEc2AwsInferentia')

' renders the element
AmazonEc2AwsInferentiaCard('AmazonEc2AwsInferentiaCard', 'Amazon Ec2 Aws Inferentia Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2AwsInferentiaCard
include('aws-q3-2021/Resource/Compute/AmazonEc2AwsInferentia')

' renders the element
AmazonEc2AwsInferentiaCard('AmazonEc2AwsInferentiaCard', 'Amazon Ec2 Aws Inferentia Card', 'an optional description')
@enduml
```

## AmazonEc2AwsInferentiaGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2AwsInferentiaGroup
include('aws-q3-2021/Resource/Compute/AmazonEc2AwsInferentia')

' renders the element
AmazonEc2AwsInferentiaGroup('AmazonEc2AwsInferentiaGroup', 'Amazon Ec2 Aws Inferentia Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2AwsInferentiaGroup
include('aws-q3-2021/Resource/Compute/AmazonEc2AwsInferentia')

' renders the element
AmazonEc2AwsInferentiaGroup('AmazonEc2AwsInferentiaGroup', 'Amazon Ec2 Aws Inferentia Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
